//
//  SCAdEnvironment.h
//  SCMobileSDK
//
//  Copyright © 2018 smartclip Holding AG. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <CoreGraphics/CGGeometry.h>

///enum DeviceType specifies the device type
///on which this is running (must be set from outside)
typedef enum DeviceType {
    deviceTypeNone = -1,
    deviceTypeMobile,
    deviceTypeTablet,
    deviceTypeDesktop,
    deviceTypeTV
} DeviceType;

///enum NetworkReachability specifies the
///type of internet connection (must be set from outside)
typedef enum NetworkReachability {
    reachabilityNone = -1,
    reachabilityWWAN,
    reachabilityWIFI,
    reachabilityUnreachable
} NetworkReachability;

///This class is used to specify certain environment variables like desired bitrate,
///deviceType and screenSize
@interface SCAdEnvironment : NSObject

/// Specify device type.
@property (nonatomic) DeviceType deviceType;

/// Specify network reachability
@property (nonatomic) NetworkReachability reachability;

/// Use a desiredBitrate, which overwrites bitrate calculation
@property (nonatomic) NSInteger desiredBitrate;

/// Value of the screenSize (if not specified, the values of the current device will be used)
@property (nonatomic) CGSize screenSize;

/// Desired mime types. Pass as array of strings
@property (nonatomic, strong) NSArray *desiredMimeTypes;
@end
